@@ -13,7 +13,6 @@
 // limitations under the License.
 
 #include <mongocxx/options/estimated_document_count.hpp>
-
 #include <mongocxx/private/read_preference.hh>
 
 #include <mongocxx/config/private/prelude.hh>
@@ -32,10 +31,21 @@ estimated_document_count& estimated_document_count::read_preference(class read_p
     return *this;
 }
 
+estimated_document_count& estimated_document_count::comment(
+    bsoncxx::types::bson_value::view_or_value comment) {
+    _comment = std::move(comment);
+    return *this;
+}
+
 const stdx::optional<std::chrono::milliseconds>& estimated_document_count::max_time() const {
     return _max_time;
 }
 
+const stdx::optional<bsoncxx::types::bson_value::view_or_value>& estimated_document_count::comment()
+    const {
+    return _comment;
+}
+
 const stdx::optional<read_preference>& estimated_document_count::read_preference() const {
     return _read_preference;
 }
