@@ -23,26 +23,34 @@
 
 namespace {
 using namespace bsoncxx::builder::basic;
-using namespace mongocxx;
 
 using bsoncxx::builder::basic::kvp;
 using bsoncxx::builder::basic::make_document;
 
 TEST_CASE("aggregate", "[aggregate][option]") {
-    instance::current();
+    mongocxx::instance::current();
 
-    options::aggregate agg;
+    mongocxx::options::aggregate agg;
 
-    auto collation = make_document(kvp("locale", "en_US"));
+    const auto collation = make_document(kvp("locale", "en_US"));
+    const auto comment = make_document(kvp("$comment", "some_comment"));
+    const auto hint = bsoncxx::document::view_or_value(make_document(kvp("_id", 1)));
+    const auto let = make_document(kvp("x", "foo"));
 
-    bsoncxx::document::view_or_value hint{make_document(kvp("_id", 1))};
+    // Avoid error: use of overloaded operator '==' is ambiguous.
+    const auto comment_value =
+        bsoncxx::types::bson_value::view_or_value(comment["$comment"].get_value());
 
     CHECK_OPTIONAL_ARGUMENT(agg, allow_disk_use, true);
     CHECK_OPTIONAL_ARGUMENT(agg, batch_size, 500);
     CHECK_OPTIONAL_ARGUMENT(agg, bypass_document_validation, true);
     CHECK_OPTIONAL_ARGUMENT(agg, collation, collation.view());
-    CHECK_OPTIONAL_ARGUMENT(agg, max_time, std::chrono::milliseconds{1000});
-    CHECK_OPTIONAL_ARGUMENT(agg, read_preference, read_preference{});
+    CHECK_OPTIONAL_ARGUMENT(agg, comment, comment_value);
     CHECK_OPTIONAL_ARGUMENT(agg, hint, hint);
+    CHECK_OPTIONAL_ARGUMENT(agg, let, let.view());
+    CHECK_OPTIONAL_ARGUMENT(agg, max_time, std::chrono::milliseconds{1000});
+    CHECK_OPTIONAL_ARGUMENT(agg, read_concern, mongocxx::read_concern());
+    CHECK_OPTIONAL_ARGUMENT(agg, read_preference, mongocxx::read_preference());
+    CHECK_OPTIONAL_ARGUMENT(agg, write_concern, mongocxx::write_concern());
 }
 }  // namespace
