@@ -13,11 +13,8 @@
 // limitations under the License.
 
 #include <set>
-#include <sstream>
 
-#include <bsoncxx/document/view.hpp>
 #include <bsoncxx/stdx/optional.hpp>
-#include <bsoncxx/stdx/string_view.hpp>
 #include <bsoncxx/string/to_string.hpp>
 #include <bsoncxx/test_util/catch.hh>
 #include <mongocxx/client.hpp>
@@ -26,20 +23,20 @@
 #include <mongocxx/test/spec/operation.hh>
 #include <mongocxx/test_util/client_helpers.hh>
 
-// Don't use SDAM Monitoring spec tests, we'd need libmongoc internals to send isMaster replies.
+// Don't use SDAM Monitoring spec tests, we'd need libmongoc internals to send hello replies.
 
 namespace {
 using namespace mongocxx;
-using bsoncxx::string::to_string;
+using bsoncxx::oid;
 using bsoncxx::builder::basic::kvp;
 using bsoncxx::builder::basic::make_document;
-using bsoncxx::oid;
+using bsoncxx::string::to_string;
 
 void open_and_close_client(const uri& test_uri, const options::apm& apm_opts) {
     // Apply listeners and trigger connection.
     options::client client_opts;
     client_opts.apm_opts(apm_opts);
-    client client{test_uri, client_opts};
+    client client{test_uri, test_util::add_test_server_api(client_opts)};
     client["admin"].run_command(make_document(kvp("ping", 1)));
 }
 
@@ -48,7 +45,7 @@ TEST_CASE("SDAM Monitoring", "[sdam_monitoring]") {
     std::string rs_name;
     uri test_uri;
 
-    client discoverer{uri{}};
+    client discoverer{uri{}, test_util::add_test_server_api()};
     auto topology_type = test_util::get_topology(discoverer);
     if (topology_type == "replicaset") {
         rs_name = test_util::replica_set_name(discoverer);
@@ -88,14 +85,14 @@ TEST_CASE("SDAM Monitoring", "[sdam_monitoring]") {
             auto new_sd = event.new_description();
             auto new_type = to_string(new_sd.type());
 
-            REQUIRE(old_sd.is_master().empty());
+            REQUIRE(old_sd.hello().empty());
             REQUIRE(to_string(old_sd.host()) == to_string(event.host()));
             REQUIRE(old_sd.port() == event.port());
             REQUIRE(old_sd.round_trip_time() == -1);
             REQUIRE(to_string(old_sd.type()) == "Unknown");
 
             REQUIRE(to_string(new_sd.host()) == to_string(event.host()));
-            REQUIRE_FALSE(new_sd.is_master().empty());
+            REQUIRE_FALSE(new_sd.hello().empty());
             REQUIRE(new_sd.port() == event.port());
             REQUIRE(new_sd.round_trip_time() >= 0);
             if (topology_type == "single") {
@@ -176,7 +173,7 @@ TEST_CASE("SDAM Monitoring", "[sdam_monitoring]") {
                 found_servers = true;
                 auto new_sd_type = to_string(new_sd.type());
                 REQUIRE(new_sd.host().length());
-                REQUIRE_FALSE(new_sd.is_master().empty());
+                REQUIRE_FALSE(new_sd.hello().empty());
                 REQUIRE(new_sd.port() > 0);
                 REQUIRE(new_sd.round_trip_time() >= 0);
                 if (topology_type == "single") {
@@ -234,7 +231,7 @@ TEST_CASE("SDAM Monitoring", "[sdam_monitoring]") {
             heartbeat_started_events++;
             REQUIRE_FALSE(event.host().empty());
             REQUIRE(event.port() != 0);
-            // Client is single-threaded, and will never perform an awaitable ismaster.
+            // Client is single-threaded, and will never perform an awaitable hello.
             REQUIRE(!event.awaited());
         });
 
@@ -244,7 +241,7 @@ TEST_CASE("SDAM Monitoring", "[sdam_monitoring]") {
             REQUIRE_FALSE(event.host().empty());
             REQUIRE(event.port() != 0);
             REQUIRE_FALSE(event.reply().empty());
-            // Client is single-threaded, and will never perform an awaitable ismaster.
+            // Client is single-threaded, and will never perform an awaitable hello.
             REQUIRE(!event.awaited());
         });
 
