@@ -222,11 +222,16 @@ void set_up_collection(const client& client,
     auto db = client[test[database_name].get_string().value];
     db.drop();
 
+    bsoncxx::builder::basic::document opts;
+    if (const auto ef = test["encrypted_fields"]) {
+        opts.append(kvp("encryptedFields", ef.get_document().value));
+    }
+
     auto coll_name = test[collection_name].get_string().value;
     auto coll = db[coll_name];
 
-    coll.drop(wc_majority);
-    coll = db.create_collection(coll_name, {}, wc_majority);
+    coll.drop(wc_majority, opts.view());
+    coll = db.create_collection(coll_name, opts.view(), wc_majority);
 
     // Set up JSON schema, if we have one
     if (test["json_schema"]) {
@@ -337,7 +342,10 @@ void run_operation_check_result(document::view op, make_op_runner_fn make_op_run
     // exception or returned an error, and that the value of the 'errorContains' field
     // matches the error string."
     if (op["result"]["errorContains"]) {
-        REQUIRE(exception);
+        if (!exception) {
+            REQUIRE(actual_result);
+            FAIL("expected an error, got: " << bsoncxx::to_json(*actual_result));
+        }
         INFO("expected error message " << op["result"]["errorContains"].get_string().value);
         INFO("got error message" << error_msg);
         // Do a case insensitive check.
@@ -353,6 +361,10 @@ void run_operation_check_result(document::view op, make_op_runner_fn make_op_run
     // command failed exception or returned an error, and that the value of the
     // 'errorCodeName' field matches the 'codeName' in the server error response."
     if (op["result"]["errorCodeName"]) {
+        if (!op_exception) {
+            REQUIRE(actual_result);
+            FAIL("expected an error, got: " << bsoncxx::to_json(*actual_result));
+        }
         REQUIRE(op_exception);
         uint32_t expected = error_code_from_name(op["result"]["errorCodeName"].get_string().value);
         REQUIRE(op_exception->code().value() == static_cast<int>(expected));
@@ -361,7 +373,10 @@ void run_operation_check_result(document::view op, make_op_runner_fn make_op_run
     // "If the result document has an 'errorLabelsContain' field, [...] Verify that all of
     // the error labels in 'errorLabelsContain' are present"
     if (op["result"]["errorLabelsContain"]) {
-        REQUIRE(op_exception);
+        if (!op_exception) {
+            REQUIRE(actual_result);
+            FAIL("expected an error, got: " << bsoncxx::to_json(*actual_result));
+        }
         for (auto&& label_el : op["result"]["errorLabelsContain"].get_array().value) {
             auto label = label_el.get_string().value;
             REQUIRE(op_exception->has_error_label(label));
@@ -371,7 +386,10 @@ void run_operation_check_result(document::view op, make_op_runner_fn make_op_run
     // "If the result document has an 'errorLabelsOmit' field, [...] Verify that none of the
     // error labels in 'errorLabelsOmit' are present."
     if (op["result"]["errorLabelsOmit"]) {
-        REQUIRE(op_exception);
+        if (!op_exception) {
+            REQUIRE(actual_result);
+            FAIL("expected an error, got: " << bsoncxx::to_json(*actual_result));
+        }
         for (auto&& label_el : op["result"]["errorLabelsOmit"].get_array().value) {
             auto label = label_el.get_string().value;
             REQUIRE(!op_exception->has_error_label(label));
